Version 0.1.1
=============

### Added
 - Documented dependencies required for the Overview notebook ([#18](https://github.com/holoviz/spatialpandas/pull/18))

### Fixed
 - Fixed Ring.to_shapely error ([#17](https://github.com/holoviz/spatialpandas/pull/17)) 

Version 0.1.0
=============

First public release available on PyPI and the pyviz anaconda channel.
